@@ -1,4 +1,4 @@
-"""Promises, promises, promises"""
+"""Promises, promises, promises."""
 from __future__ import absolute_import, unicode_literals
 
 import re
@@ -14,7 +14,7 @@ from .funtools import (
 )
 
 
-__version__ = '1.1.2'
+__version__ = '1.1.3'
 __author__ = 'Ask Solem'
 __contact__ = 'ask@celeryproject.org'
 __homepage__ = 'http://github.com/celery/vine'
